@@ -20,6 +20,7 @@
 #include <gpe/picturebutton.h>
 #include <gpe/pim-categories-ui.h>
 #include <gpe/spacing.h>
+#include <libdisplaymigration/displaymigration.h>
 
 #include "support.h"
 #include "structure.h"
@@ -28,6 +29,7 @@
 #include "namedetail.h"
 
 void on_edit_cancel_clicked (GtkButton * button, gpointer user_data);
+void on_edit_window_closed_clicked (gpointer user_data);
 void on_edit_save_clicked (GtkButton * button, gpointer user_data);
 void on_edit_bt_image_clicked (GtkWidget *image, gpointer user_data);
 void on_categories_clicked (GtkButton *button, gpointer user_data);
@@ -45,17 +47,23 @@ void on_unknown_year_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 void on_name_clicked (GtkButton *button, gpointer user_data);
 
 
-
 /* this is the filter for phone number edits */
-static gboolean
-phone_key_press_event (GtkWidget *widget, GdkEventKey *k, gpointer p)
+void
+on_phone_insert_text(GtkEditable *editable, gchar *new_text,
+                     gint new_text_length, gint *position,
+                     gpointer user_data)
 {
-  if (!strstr(" +0123456789-/()", k->string) 
-      && !(k->state & GDK_CONTROL_MASK))
-    {
-      return TRUE;
-    }
-  return FALSE;
+  int i;
+  gboolean isok = TRUE;
+  
+  for (i = 0; i < new_text_length; i++)
+    if (!strchr(" +0123456789-/()", new_text[i]))
+      {
+        isok = FALSE;
+        break;
+      }
+  if (!isok)
+    gtk_signal_emit_stop_by_name(GTK_OBJECT(editable), "insert-text");
 }
 
 static void
@@ -90,8 +98,8 @@ pop_singles (GtkWidget *vbox, GSList *list, GtkWidget *pw, gboolean visible)
               || strstr(e->tag,".MOBILE") 
               || strstr(e->tag,".FAX"))
             {
-               g_signal_connect (G_OBJECT (w), "key_press_event", 
-		         G_CALLBACK (phone_key_press_event), NULL);
+              g_signal_connect (G_OBJECT (w), "insert-text", 
+		         G_CALLBACK (on_phone_insert_text), NULL);
             }
           if (strcasecmp(e->tag, "NAME")) /* the name field on a button */
             {
@@ -103,6 +111,7 @@ pop_singles (GtkWidget *vbox, GSList *list, GtkWidget *pw, gboolean visible)
               GtkWidget *b, *h;
               h = gtk_hbox_new(FALSE, gpe_get_boxspacing());
               l = gtk_label_new (e->name);
+              gtk_misc_set_alignment(GTK_MISC(l),1.0,0.5);
               gtk_box_pack_start(GTK_BOX(h), w, TRUE, TRUE, 0);
               GTK_WIDGET_SET_FLAGS(w, GTK_CAN_DEFAULT);
               b = gtk_button_new_with_label(_("Details"));
@@ -134,7 +143,8 @@ pop_singles (GtkWidget *vbox, GSList *list, GtkWidget *pw, gboolean visible)
         gtk_widget_show_all(table);
       else
         gtk_widget_hide_all(table);
-      gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 4);
+
+      gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, TRUE, 4);
     }
 }
 
@@ -307,7 +317,7 @@ edit_window_key_press_event (GtkWidget *widget, GdkEventKey *k, GtkWidget *user_
 {
   if (k->keyval == GDK_Escape) 
   {
-    gtk_widget_destroy (GTK_WIDGET (user_data));
+    on_edit_window_closed_clicked(GTK_WIDGET (user_data));
     return TRUE;
   }
   if (k->keyval == GDK_Return) 
@@ -329,11 +339,8 @@ create_edit (void)
   GtkWidget *edit_cancel;
   GtkWidget *edit_save;
   GtkWidget *edit_delete = NULL;
-  GtkTooltips *tooltips;
   GtkWidget *vbox, *action_area;
 
-  tooltips = gtk_tooltips_new ();
-
   if (mode_large_screen)
     {
       edit = gtk_dialog_new ();
@@ -377,6 +384,11 @@ create_edit (void)
 		    G_CALLBACK (on_edit_cancel_clicked), edit);
   g_signal_connect (G_OBJECT (edit_save), "clicked",
 		    G_CALLBACK (on_edit_save_clicked), edit);
+
+  /* Call the on_edit_window_closed_clicked function when the window is destroyed,
+   * otherwise the new button gets disabled */
+  g_signal_connect (G_OBJECT (edit), "delete_event",
+		  	G_CALLBACK (on_edit_window_closed_clicked), edit);
             
   g_signal_connect (G_OBJECT (action_area), "key_press_event", 
 		    G_CALLBACK (action_area_key_press_event), notebook2);
@@ -385,7 +397,6 @@ create_edit (void)
   g_signal_connect (G_OBJECT (edit), "key_press_event", 
 		    G_CALLBACK (edit_window_key_press_event), edit);
 
-  g_object_set_data (G_OBJECT (edit), "tooltips", tooltips);
   g_object_set_data (G_OBJECT (edit), "notebook2", notebook2);
 
   if (mode_large_screen)
@@ -399,6 +410,8 @@ create_edit (void)
       else
         gtk_window_set_default_size (GTK_WINDOW (edit), 240, 320);
     }
+  
+  displaymigration_mark_window (edit);
 
   return edit;
 }
@@ -1008,6 +1021,19 @@ on_edit_cancel_clicked (GtkButton * button, gpointer user_data)
   gtk_widget_destroy (GTK_WIDGET (edit));
 }
 
+void
+on_edit_window_closed_clicked (gpointer user_data)
+{
+  GtkWidget *edit = user_data;
+  if (g_object_get_data(G_OBJECT(edit), "isdialog"))
+    {
+      gtk_main_quit();
+      exit(EXIT_SUCCESS);
+    }
+  update_display ();
+  gtk_widget_destroy (GTK_WIDGET (edit));
+}
+
 void        
 tv_move_cursor (GtkTextView *textview,
                 GtkMovementStep arg1,
